@@ -1,7 +1,7 @@
 """
 Implements automatic calibration
 
-This module defines the `perform_autofit` function, which is the entry-point for
+This module defines the :func:`calibrate` function, which is the entry-point for
 automatic calibration
 
 """
@@ -11,10 +11,13 @@ import sciris as sc
 from .model import BadInitialization
 from .system import logger
 from .parameters import ParameterSet
+import logging
+
+__all__ = ["calibrate"]
 
 # TODO: Determine whether this is necessary.
 calibration_settings = dict()
-calibration_settings['tolerance'] = 1e-6
+calibration_settings["tolerance"] = 1e-6
 
 
 def _update_parset(parset, y_factors, pars_to_adjust):
@@ -30,14 +33,14 @@ def _update_parset(parset, y_factors, pars_to_adjust):
         pop_name = x[1]
 
         if par_name in parset.pars:
-            if pop_name == 'all':
+            if pop_name == "all":
                 par = parset.pars[par_name]
                 par.meta_y_factor = y_factors[i]
             else:
                 parset.pars[par_name].y_factor[pop_name] = y_factors[i]
         else:
             # Handle transfers here
-            tokens = par_name.split('_from_')
+            tokens = par_name.split("_from_")
             par = parset.transfers[tokens[0]][tokens[1]]
             par.y_factor[pop_name] = y_factors[i]
             raise NotImplementedError
@@ -61,7 +64,7 @@ def _calculate_objective(y_factors, pars_to_adjust, output_quantities, parset, p
         target = project.data.get_ts(var_label, pop_name)  # This is the TimeSeries with the data for the requested quantity
         if target is None:
             continue
-        if not target.has_time_data:     # Only use this output quantity if the user entered time-specific data
+        if not target.has_time_data:  # Only use this output quantity if the user entered time-specific data
             continue
         var = result.model.get_pop(pop_name).get_variable(var_label)
         data_t, data_v = target.get_arrays()
@@ -79,23 +82,17 @@ def _calculate_objective(y_factors, pars_to_adjust, output_quantities, parset, p
 
 
 def _get_fitscore_func(metric):
-    """
-
-
-    """
+    """"""
     availfns = globals().copy()
     availfns.update(locals())
     try:
-        return availfns.get('_calc_%s' % metric)
+        return availfns.get("_calc_%s" % metric)
     except Exception:
         raise NotImplementedError("No method associated with _calc_%s (calibration.py)" % metric)
 
 
 def _calculate_fitscore(y_obs, y_fit, metric="meansquare"):
-    """
-
-
-    """
+    """"""
     return _get_fitscore_func(metric)(y_obs, y_fit)
 
 
@@ -116,12 +113,11 @@ def _calc_wape(y_obs, y_fit):
     """
     Calculates the weighted absolute percentage error
     """
-    return abs(y_fit - y_obs) / (y_obs.mean() + calibration_settings['tolerance'])
+    return abs(y_fit - y_obs) / (y_obs.mean() + calibration_settings["tolerance"])
 
 
-def calibrate(project, parset: ParameterSet, pars_to_adjust, output_quantities, max_time=60, method='asd') -> ParameterSet:
+def calibrate(project, parset: ParameterSet, pars_to_adjust, output_quantities, max_time=60, method="asd") -> ParameterSet:
     """
-
     Run automated calibration
 
     :param project: A project instance to provide data and sim settings
@@ -160,14 +156,11 @@ def calibrate(project, parset: ParameterSet, pars_to_adjust, output_quantities,
             o2.append(output_tuple)
     output_quantities = o2
 
-    original_sim_end = project.settings.sim_end
-    project.settings.sim_end = min(project.data.tvec[-1], original_sim_end)
-
     args = {
-        'project': project,
-        'parset': parset.copy(),
-        'pars_to_adjust': pars_to_adjust,
-        'output_quantities': output_quantities,
+        "project": project,
+        "parset": parset.copy(),
+        "pars_to_adjust": pars_to_adjust,
+        "output_quantities": output_quantities,
     }
 
     x0 = []
@@ -177,56 +170,62 @@ def calibrate(project, parset: ParameterSet, pars_to_adjust, output_quantities,
         par_name, pop_name, scale_min, scale_max = x
         if par_name in parset.pars:
             par = parset.pars[par_name]
-            if pop_name == 'all':
+            if pop_name == "all":
                 x0.append(par.meta_y_factor)
             else:
                 x0.append(par.y_factor[pop_name])
         else:
-            tokens = par_name.split('_from_')
+            tokens = par_name.split("_from_")
             par = parset.transfers[tokens[0]][tokens[1]]
             x0.append(par.y_factor[pop_name])
         xmin.append(scale_min)
         xmax.append(scale_max)
 
-    if method == 'asd':
-        optim_args = {
-            'stepsize': 0.1,
-            'maxiters': 2000,
-            'sinc': 1.5,
-            'sdec': 2.,
-            'fulloutput': False,
-            'reltol': 1e-3,
-            'abstol': 1e-6,
-            'xmin': xmin,
-            'xmax': xmax,
-        }
+    original_sim_end = project.settings.sim_end
+    project.settings.sim_end = min(project.data.tvec[-1], original_sim_end)
 
-        if max_time is not None:
-            optim_args['maxtime'] = max_time
+    try:
+        if method == "asd":
+            optim_args = {
+                "stepsize": 0.1,
+                "maxiters": 2000,
+                "sinc": 1.5,
+                "sdec": 2.0,
+                "fulloutput": False,
+                "reltol": 1e-3,
+                "abstol": 1e-6,
+                "xmin": xmin,
+                "xmax": xmax,
+            }
 
-        opt_result = sc.asd(_calculate_objective, x0, args, **optim_args)
-        x1 = opt_result['x']
+            if max_time is not None:
+                optim_args["maxtime"] = max_time
 
-    elif method == 'pso':
-        import pyswarm
+            log_level = logger.getEffectiveLevel()
+            if log_level < logging.WARNING:
+                optim_args["verbose"] = 2
+            else:
+                optim_args["verbose"] = 0
 
-        optim_args = {
-            'maxiter': 3,
-            'lb': xmin,
-            'ub': xmax,
-            'minstep': 1e-3,
-            'debug': True
-        }
-        if np.any(~np.isfinite(xmin)) or np.any(~np.isfinite(xmax)):
-            errormsg = 'PSO optimization requires finite upper and lower bounds to specify the search domain (i.e. every parameter being adjusted needs to have finite bounds)'
-            raise Exception(errormsg)
+            opt_result = sc.asd(_calculate_objective, x0, args, **optim_args)
+            x1 = opt_result["x"]
+        elif method == "pso":
+            import pyswarm
 
-        x1, _ = pyswarm.pso(_calculate_objective, kwargs=args, **optim_args)
+            optim_args = {"maxiter": 3, "lb": xmin, "ub": xmax, "minstep": 1e-3, "debug": True}
+            if np.any(~np.isfinite(xmin)) or np.any(~np.isfinite(xmax)):
+                errormsg = "PSO optimization requires finite upper and lower bounds to specify the search domain (i.e. every parameter being adjusted needs to have finite bounds)"
+                raise Exception(errormsg)
 
-    else:
-        raise Exception('Unrecognized method')
+            x1, _ = pyswarm.pso(_calculate_objective, kwargs=args, **optim_args)
+        else:
+            raise Exception("Unrecognized method")
+    except Exception as e:
+        raise e
+    finally:
+        project.settings.sim_end = original_sim_end  # Restore the simulation end year
 
-    _update_parset(args['parset'], x1, pars_to_adjust)
+    _update_parset(args["parset"], x1, pars_to_adjust)
 
     # Log out the commands required for equivalent manual calibration if desired
     for i, x in enumerate(pars_to_adjust):
@@ -234,22 +233,19 @@ def calibrate(project, parset: ParameterSet, pars_to_adjust, output_quantities,
         pop_name = x[1]
 
         if par_name in parset.pars:
-            par = args['parset'].pars[par_name]
+            par = args["parset"].pars[par_name]
 
-            if pop_name == 'all':
+            if pop_name == "all":
                 logger.debug("parset.get_par('{}').meta_y_factor={:.2f}".format(par_name, par.meta_y_factor))
             else:
                 logger.debug("parset.get_par('{}').y_factor['{}']={:.2f}".format(par_name, pop_name, par.y_factor[pop_name]))
 
         else:
-            tokens = par_name.split('_from_')
-            par = args['parset'].transfers[tokens[0]][tokens[1]]
-            logger.debug("parset.transfers['{}']['{}'].y_factor['{}']={:.2f}".format(tokens[0], tokens[1], pop_name,
-                                                                                     par.y_factor[pop_name]))
+            tokens = par_name.split("_from_")
+            par = args["parset"].transfers[tokens[0]][tokens[1]]
+            logger.debug("parset.transfers['{}']['{}'].y_factor['{}']={:.2f}".format(tokens[0], tokens[1], pop_name, par.y_factor[pop_name]))
             raise NotImplementedError  # Transfers might be handled differently in Atomica
 
-    args['parset'].name = 'calibrated_' + args['parset'].name
+    args["parset"].name = "calibrated_" + args["parset"].name
 
-    project.settings.sim_end = original_sim_end  # Restore the simulation end year
-
-    return args['parset']
+    return args["parset"]
